@@ -13,11 +13,11 @@
 #' @param queries the queries to set
 #' @return the object given as first argument
 #' @examples
-#' upsetjs() %>% fromList(list(a=c(1,2,3), b=c(2,3))) %>%
-#' setQueries(list(list(name="Q1", color="red", set="b")))
-#'
+#' upsetjs() %>%
+#'   fromList(list(a = c(1, 2, 3), b = c(2, 3))) %>%
+#'   setQueries(list(list(name = "Q1", color = "red", set = "b")))
 #' @export
-setQueries = function(upsetjs, queries = list()) {
+setQueries <- function(upsetjs, queries = list()) {
   checkUpSetCommonArgument(upsetjs)
   stopifnot(is.list(queries))
   setProperty(upsetjs, "queries", queries)
@@ -32,19 +32,20 @@ setQueries = function(upsetjs, queries = list()) {
 #' @param set the set name, similar to the selection
 #' @return the object given as first argument
 #' @examples
-#' upsetjs() %>% fromList(list(a=c(1,2,3), b=c(2,3))) %>% addQuery(name="Q1", color="red", set="b")
-#'
+#' upsetjs() %>%
+#'   fromList(list(a = c(1, 2, 3), b = c(2, 3))) %>%
+#'   addQuery(name = "Q1", color = "red", set = "b")
 #' @export
-addQuery = function(upsetjs,
-                    name,
-                    color,
-                    elems = NULL,
-                    set = NULL) {
+addQuery <- function(upsetjs,
+                     name,
+                     color,
+                     elems = NULL,
+                     set = NULL) {
   checkUpSetCommonArgument(upsetjs)
   stopifnot(is.character(name), length(name) == 1)
   stopifnot(is.character(color), length(color) == 1)
   stopifnot((is.character(set) &&
-               length(set) >= 1) || is.vector(elems))
+    length(set) >= 1) || is.vector(elems))
 
   appendProperty(upsetjs, "queries", cleanNull(list(
     name = name,
@@ -60,11 +61,12 @@ addQuery = function(upsetjs,
 #' @param upsetjs an object of class \code{upsetjs} or \code{upsetjs_proxy}
 #' @return the object given as first argument
 #' @examples
-#' upsetjs() %>% fromList(list(a=c(1,2,3), b=c(2,3))) %>%
-#' addQuery(name="Q1", color="red", set="b") %>% clearQueries()
-#'
+#' upsetjs() %>%
+#'   fromList(list(a = c(1, 2, 3), b = c(2, 3))) %>%
+#'   addQuery(name = "Q1", color = "red", set = "b") %>%
+#'   clearQueries()
 #' @export
-clearQueries = function(upsetjs) {
+clearQueries <- function(upsetjs) {
   checkUpSetCommonArgument(upsetjs)
 
   setProperty(upsetjs, "queries", NULL)
@@ -77,11 +79,12 @@ clearQueries = function(upsetjs) {
 #' @param value whether to enable or disable
 #' @return the object given as first argument
 #' @examples
-#' upsetjs() %>% fromList(list(a=c(1,2,3), b=c(2,3))) %>%
-#' addQuery(name="Q1", color="red", set="b") %>% queryLegend(FALSE)
-#'
+#' upsetjs() %>%
+#'   fromList(list(a = c(1, 2, 3), b = c(2, 3))) %>%
+#'   addQuery(name = "Q1", color = "red", set = "b") %>%
+#'   queryLegend(FALSE)
 #' @export
-queryLegend = function(upsetjs, value = TRUE) {
+queryLegend <- function(upsetjs, value = TRUE) {
   checkUpSetCommonArgument(upsetjs)
   stopifnot(is.logical(value), length(value) == 1)
 
